@@ -4,13 +4,12 @@ use serde::de::DeserializeOwned;
 use serde::Serialize;
 
 use crate::aggregate::Aggregate;
-use crate::event::{EventEnvelope};
+use crate::event::EventEnvelope;
 
 /// Each CQRS platform should have one or more `QueryProcessor`s where it will distribute committed
 /// events, it is the responsibility of the `QueryProcessor` to update any interested
 /// queries.
-pub trait QueryProcessor<A: Aggregate>
-{
+pub trait QueryProcessor<A: Aggregate> {
     /// Events will be dispatched here immediately after being committed for the downstream queries
     /// to be updated.
     fn dispatch(&self, aggregate_id: &str, events: &[EventEnvelope<A>]);
@@ -22,13 +21,8 @@ pub trait QueryProcessor<A: Aggregate>
 ///
 /// Queries are generally serialized for persistence, usually in a standard database, but a query
 /// could also utilize messaging platform or other asynchronous, eventually-consistent systems.
-pub trait Query<A: Aggregate>: Debug + Default + Serialize + DeserializeOwned
-{
+pub trait Query<A: Aggregate>: Debug + Default + Serialize + DeserializeOwned {
     /// Each implemented query is responsible for updating its stated based on events passed via
     /// this method.
     fn update(&mut self, event: &EventEnvelope<A>);
 }
-
-
-
-
