@@ -1,20 +1,13 @@
 use std::collections::HashMap;
 use std::sync::{Arc, RwLock};
 
-use chrono::Utc;
 use serde::{Deserialize, Serialize};
 use static_assertions::assert_impl_all;
 
-use cqrs_es::{Aggregate,
-              AggregateError,
-              CqrsFramework,
-              DomainEvent,
-              EventEnvelope,
-              EventStore,
-};
 use cqrs_es::mem_store::{MemStore, MemStoreAggregateContext};
-use cqrs_es::QueryProcessor;
 use cqrs_es::test::TestFramework;
+use cqrs_es::QueryProcessor;
+use cqrs_es::{Aggregate, AggregateError, CqrsFramework, DomainEvent, EventEnvelope, EventStore};
 
 #[derive(Debug, Serialize, Deserialize)]
 pub struct TestAggregate {
@@ -27,12 +20,16 @@ impl Aggregate for TestAggregate {
     type Command = TestCommand;
     type Event = TestEvent;
 
-    fn aggregate_type() -> &'static str { "TestAggregate" }
+    fn aggregate_type() -> &'static str {
+        "TestAggregate"
+    }
 
     fn handle(&self, command: TestCommand) -> Result<Vec<TestEvent>, AggregateError> {
         match &command {
             TestCommand::CreateTest(command) => {
-                let event = TestEvent::Created(Created { id: command.id.to_string() });
+                let event = TestEvent::Created(Created {
+                    id: command.id.to_string(),
+                });
                 Ok(vec![event])
             }
 
@@ -42,12 +39,16 @@ impl Aggregate for TestAggregate {
                         return Err(AggregateError::new("test already performed"));
                     }
                 }
-                let event = TestEvent::Tested(Tested { test_name: command.test_name.to_string() });
+                let event = TestEvent::Tested(Tested {
+                    test_name: command.test_name.to_string(),
+                });
                 Ok(vec![event])
             }
 
             TestCommand::DoSomethingElse(command) => {
-                let event = TestEvent::SomethingElse(SomethingElse { description: command.description.clone() });
+                let event = TestEvent::SomethingElse(SomethingElse {
+                    description: command.description.clone(),
+                });
                 Ok(vec![event])
             }
         }
@@ -78,7 +79,6 @@ impl Default for TestAggregate {
     }
 }
 
-
 #[derive(Debug, Serialize, Deserialize, Clone, PartialEq)]
 pub enum TestEvent {
     Created(Created),
@@ -88,17 +88,17 @@ pub enum TestEvent {
 
 #[derive(Debug, Serialize, Deserialize, Clone, PartialEq)]
 pub struct Created {
-    pub id: String
+    pub id: String,
 }
 
 #[derive(Debug, Serialize, Deserialize, Clone, PartialEq)]
 pub struct Tested {
-    pub test_name: String
+    pub test_name: String,
 }
 
 #[derive(Debug, Serialize, Deserialize, Clone, PartialEq)]
 pub struct SomethingElse {
-    pub description: String
+    pub description: String,
 }
 
 impl DomainEvent for TestEvent {}
@@ -122,11 +122,13 @@ pub struct DoSomethingElse {
 }
 
 struct TestView {
-    events: Arc<RwLock<Vec<EventEnvelope<TestAggregate>>>>
+    events: Arc<RwLock<Vec<EventEnvelope<TestAggregate>>>>,
 }
 
 impl TestView {
-    fn new(events: Arc<RwLock<Vec<EventEnvelope<TestAggregate>>>>) -> Self { TestView { events } }
+    fn new(events: Arc<RwLock<Vec<EventEnvelope<TestAggregate>>>>) -> Self {
+        TestView { events }
+    }
 }
 
 impl QueryProcessor<TestAggregate> for TestView {
@@ -146,9 +148,9 @@ assert_impl_all!(aggregate; TestAggregate,Aggregate);
 assert_impl_all!(memstore; MemStore::<TestAggregate>, EventStore::<TestAggregate,MemStoreAggregateContext<TestAggregate>>);
 
 fn metadata() -> HashMap<String, String> {
-    let now = Utc::now();
+    let now = "2021-03-18T12:32:45.930Z".to_string();
     let mut metadata = HashMap::new();
-    metadata.insert("time".to_string(), now.to_rfc3339());
+    metadata.insert("time".to_string(), now);
     metadata
 }
 
@@ -160,16 +162,36 @@ fn test_mem_store() {
     assert_eq!(0, initial_events.len());
     let agg_context = event_store.load_aggregate(&id);
 
-    event_store.commit(vec![TestEvent::Created(Created { id: "test_event_A".to_string() })], agg_context, metadata()).unwrap();
+    event_store
+        .commit(
+            vec![TestEvent::Created(Created {
+                id: "test_event_A".to_string(),
+            })],
+            agg_context,
+            metadata(),
+        )
+        .unwrap();
     let stored_events = event_store.load(&id);
     assert_eq!(1, stored_events.len());
     let agg_context = event_store.load_aggregate(&id);
 
-    event_store.commit(vec![
-        TestEvent::Tested(Tested { test_name: "test A".to_string() }),
-        TestEvent::Tested(Tested { test_name: "test B".to_string() }),
-        TestEvent::SomethingElse(SomethingElse { description: "something else happening here".to_string() }),
-    ], agg_context, metadata()).unwrap();
+    event_store
+        .commit(
+            vec![
+                TestEvent::Tested(Tested {
+                    test_name: "test A".to_string(),
+                }),
+                TestEvent::Tested(Tested {
+                    test_name: "test B".to_string(),
+                }),
+                TestEvent::SomethingElse(SomethingElse {
+                    description: "something else happening here".to_string(),
+                }),
+            ],
+            agg_context,
+            metadata(),
+        )
+        .unwrap();
     let stored_envelopes = event_store.load(&id);
 
     let mut agg = TestAggregate::default();
@@ -187,12 +209,24 @@ fn test_framework_test() {
     let test_name = "test A";
     let test_framework = ThisTestFramework::default();
 
-    test_framework.given(vec![TestEvent::Created(Created { id: "test_id_A".to_string() })])
-        .when(TestCommand::ConfirmTest(ConfirmTest { test_name: test_name.to_string() }))
-        .then_expect_events(vec![TestEvent::Tested(Tested { test_name: test_name.to_string() })]);
+    test_framework
+        .given(vec![TestEvent::Created(Created {
+            id: "test_id_A".to_string(),
+        })])
+        .when(TestCommand::ConfirmTest(ConfirmTest {
+            test_name: test_name.to_string(),
+        }))
+        .then_expect_events(vec![TestEvent::Tested(Tested {
+            test_name: test_name.to_string(),
+        })]);
 
-    test_framework.given(vec![TestEvent::Tested(Tested { test_name: test_name.to_string() })])
-        .when(TestCommand::ConfirmTest(ConfirmTest { test_name: test_name.to_string() }))
+    test_framework
+        .given(vec![TestEvent::Tested(Tested {
+            test_name: test_name.to_string(),
+        })])
+        .when(TestCommand::ConfirmTest(ConfirmTest {
+            test_name: test_name.to_string(),
+        }))
         .then_expect_error("test already performed")
 }
 
@@ -202,9 +236,16 @@ fn test_framework_failure_test() {
     let test_name = "test A";
     let test_framework = ThisTestFramework::default();
 
-    test_framework.given(vec![TestEvent::Tested(Tested { test_name: test_name.to_string() })])
-        .when(TestCommand::ConfirmTest(ConfirmTest { test_name: test_name.to_string() }))
-        .then_expect_events(vec![TestEvent::Tested(Tested { test_name: test_name.to_string() })]);
+    test_framework
+        .given(vec![TestEvent::Tested(Tested {
+            test_name: test_name.to_string(),
+        })])
+        .when(TestCommand::ConfirmTest(ConfirmTest {
+            test_name: test_name.to_string(),
+        }))
+        .then_expect_events(vec![TestEvent::Tested(Tested {
+            test_name: test_name.to_string(),
+        })]);
 }
 
 #[test]
@@ -213,8 +254,13 @@ fn test_framework_failure_test_b() {
     let test_name = "test A";
     let test_framework = ThisTestFramework::default();
 
-    test_framework.given(vec![TestEvent::Created(Created { id: "test_id_A".to_string() })])
-        .when(TestCommand::ConfirmTest(ConfirmTest { test_name: test_name.to_string() }))
+    test_framework
+        .given(vec![TestEvent::Created(Created {
+            id: "test_id_A".to_string(),
+        })])
+        .when(TestCommand::ConfirmTest(ConfirmTest {
+            test_name: test_name.to_string(),
+        }))
         .then_expect_error("some error message")
 }
 
@@ -230,24 +276,54 @@ fn framework_test() {
     let uuid = uuid::Uuid::new_v4().to_string();
     let id = uuid.clone();
     let metadata = metadata();
-    cqrs.execute_with_metadata(&id, TestCommand::ConfirmTest(ConfirmTest { test_name: uuid.clone() }), metadata).unwrap_or_default();
+    cqrs.execute_with_metadata(
+        &id,
+        TestCommand::ConfirmTest(ConfirmTest {
+            test_name: uuid.clone(),
+        }),
+        metadata,
+    )
+    .unwrap_or_default();
 
     assert_eq!(1, stored_events.read().unwrap().len());
     assert_eq!(1, delivered_events.read().unwrap().len());
 
     let test = "TEST_A";
     let id = uuid.clone();
-    cqrs.execute(&id, TestCommand::ConfirmTest(ConfirmTest { test_name: test.to_string() })).unwrap_or_default();
+    cqrs.execute(
+        &id,
+        TestCommand::ConfirmTest(ConfirmTest {
+            test_name: test.to_string(),
+        }),
+    )
+    .unwrap_or_default();
 
     assert_eq!(2, delivered_events.read().unwrap().len());
-    let stored_event_count = stored_events.read().unwrap().get(uuid.clone().as_str()).unwrap().len();
+    let stored_event_count = stored_events
+        .read()
+        .unwrap()
+        .get(uuid.clone().as_str())
+        .unwrap()
+        .len();
     assert_eq!(2, stored_event_count);
 
     let id = uuid.clone();
-    let err = cqrs.execute(&id, TestCommand::ConfirmTest(ConfirmTest { test_name: test.to_string() })).unwrap_err();
+    let err = cqrs
+        .execute(
+            &id,
+            TestCommand::ConfirmTest(ConfirmTest {
+                test_name: test.to_string(),
+            }),
+        )
+        .unwrap_err();
     assert_eq!(AggregateError::new("test already performed"), err);
 
     assert_eq!(2, delivered_events.read().unwrap().len());
-    let stored_event_count = stored_events.read().unwrap().get(uuid.clone().as_str()).unwrap().len();
+    let stored_event_count = stored_events
+        .read()
+        .unwrap()
+        .get(uuid.clone().as_str())
+        .unwrap()
+        .len();
     assert_eq!(2, stored_event_count);
 }
